@@ -3,20 +3,18 @@ package XML::Grammar::Builder;
 use strict;
 use warnings;
 
-use base 'Test::Run::Builder';
-
-use File::Find;
+use parent 'Test::Run::Builder';
 
 our $VERSION = '0.0200';
 
 sub new
 {
     my $package = shift;
-    my %args = @_;
+    my %args    = @_;
     my @extradata_files;
 
     my $builder = $package->SUPER::new(
-        share_dir => 'extradata',
+        share_dir               => 'extradata',
         auto_configure_requires => 1,
         @_
     );
@@ -24,7 +22,6 @@ sub new
     return $builder;
 }
 
-
 =begin excluded
 
     my $get_dest_extradata_cb = sub {
