@@ -1,5 +1,5 @@
 package XML::Grammar::Fiction::FromProto;
-$XML::Grammar::Fiction::FromProto::VERSION = '0.22.2';
+$XML::Grammar::Fiction::FromProto::VERSION = '0.22.3';
 use strict;
 use warnings;
 use autodie;
@@ -24,7 +24,7 @@ around '_calc_passthrough_cb' => sub {
 
     if ( $lookup{$name} )
     {
-        return $name;
+        return +{ tag => $name, wrap_para => 0, };
     }
 
     return $orig->( $self, @_ );
@@ -321,7 +321,7 @@ on failure.
 
 =head1 VERSION
 
-version 0.22.2
+version 0.22.3
 
 =for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
