@@ -1,5 +1,5 @@
 package XML::Grammar::FictionBase::FromProto::Parser::XmlIterator;
-$XML::Grammar::FictionBase::FromProto::Parser::XmlIterator::VERSION = '0.22.2';
+$XML::Grammar::FictionBase::FromProto::Parser::XmlIterator::VERSION = '0.22.3';
 use strict;
 use warnings;
 
@@ -58,7 +58,15 @@ sub _push_tag
 {
     my $self = shift;
 
-    push( @{ $self->_tags_stack }, @_ );
+    my $tag = shift;
+
+    die if @_;
+
+    if ( @{ $self->_tags_stack } )
+    {
+        die if $tag->name eq 'para' and $self->_top_is_para();
+    }
+    push( @{ $self->_tags_stack }, $tag );
 
     return;
 }
@@ -791,8 +799,12 @@ sub _handle_open_tag
     }
     else
     {
-        $self->_push_tag($open);
+        my $cb = sub {
+            $self->_push_tag($open);
+        };
 
+
+        $cb->();
         return;
     }
 }
@@ -921,25 +933,9 @@ __END__
 
 =encoding UTF-8
 
-=head1 NAME
-
-XML::Grammar::FictionBase::FromProto::Parser::XmlIterator - line iterator base
-class with some nested XMLisms.
-
-B<For internal use only>.
-
 =head1 VERSION
 
-version 0.22.2
-
-=head1 SYNOPSIS
-
-B<TODO:> write one.
-
-=head1 DESCRIPTION
-
-This is a line iterator with some features for parsing, nested,
-XML-like grammars.
+version 0.22.3
 
 =begin Removed # Not supported by Moo / MooX yet.
 
@@ -970,6 +966,36 @@ XML-like grammars.
 
 =end Removed
 
+=begin removed if ( $self->_in_para()
+            or ( not exists +{ b => 1, i => 1, }->{ $open->name() } ) )
+        {
+            $cb->();
+        }
+        else
+        {
+            warn "before _new_para[[["
+                . join( ",", map { $_->name() } @{ $self->_tags_stack } ) . "; "
+                . ${ $self->curr_line_ref } . "]]]";
+            $self->_new_para( [] );
+            $cb->();
+        }
+=end removed
+
+=head1 NAME
+
+XML::Grammar::FictionBase::FromProto::Parser::XmlIterator - line iterator base
+class with some nested XMLisms.
+
+B<For internal use only>.
+=head1 SYNOPSIS
+
+B<TODO:> write one.
+
+=head1 DESCRIPTION
+
+This is a line iterator with some features for parsing, nested,
+XML-like grammars.
+
 =head1 METHODS
 
 =head2 $self->process_text($string)
@@ -980,6 +1006,9 @@ Processes the text and returns the parse tree.
 
 Leftover from Moo.
 
+
+=end removed
+
 =for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
