@@ -1,5 +1,5 @@
 package XML::Grammar::FictionBase::TagsTree2XML;
-$XML::Grammar::FictionBase::TagsTree2XML::VERSION = '0.22.2';
+$XML::Grammar::FictionBase::TagsTree2XML::VERSION = '0.22.3';
 use strict;
 use warnings;
 
@@ -152,12 +152,21 @@ sub _write_Element_Paragraph
 {
     my ( $self, $elem ) = @_;
 
-    return $self->_output_tag_with_childs(
-        {
-            start => [ $self->_paragraph_tag() ],
-            elem  => $elem,
-        },
+    my $out_cb = sub {
+        return $self->_write_elem_childs( $elem, );
+    };
+    return (
+        ( $self->_writer->within_element( $self->_paragraph_tag ) )
+        ? $out_cb->()
+        : $self->_output_tag(
+            {
+                start => [ $self->_paragraph_tag, ],
+                in    => $out_cb,
+            }
+        )
     );
+
+    # ( $self->_writer->within_element( $self->_paragraph_tag ) )
 }
 
 sub _write_Element_Element
@@ -273,11 +282,33 @@ sub _write_Element_elem
         defined( my $out_name = $self->_calc_passthrough_name( $name, $elem ) )
         )
     {
-        return $self->_output_tag_with_childs(
-            {
-                start => [$out_name],
-                elem  => $elem,
-            }
+        if ( "" eq ref $out_name )
+        {
+            $out_name = { tag => $out_name, wrap_para => 1, };
+        }
+        my $out_cb = sub {
+            return $self->_output_tag_with_childs(
+                {
+                    start => [ $out_name->{tag} ],
+                    elem  => $elem,
+                }
+            );
+        };
+
+        # warn "\$out_name=[$out_name]";
+        return (
+            (
+                $out_name->{wrap_para}
+                    && (
+                    !$self->_writer->within_element( $self->_paragraph_tag ) )
+            )
+            ? $self->_output_tag(
+                {
+                    start => [ $self->_paragraph_tag, ],
+                    in    => $out_cb,
+                }
+                )
+            : $out_cb->()
         );
     }
     else
@@ -454,7 +485,7 @@ Internal - (to settle pod-coverage.).
 
 =head1 VERSION
 
-version 0.22.2
+version 0.22.3
 
 =for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
